@@ -116,14 +116,14 @@ def start_workers(mode, urls, num_workers):
                     if proc.exitcode == 0:
                         procs[proc] = False
                     else:
-                        msg = "Worker process failed (exit code %d)"\
+                        msg = 'Worker process failed (exit code %d)'\
                                % proc.exitcode
                         exit(msg, proc.exitcode)
 
 def process_urls(mode, urls, verbose, num_workers):
 
     if verbose:
-        print("%sing %d files.." % (mode.capitalize(), len(urls)),
+        print('%sing %d files..' % (mode.capitalize(), len(urls)),
               file=sys.stderr)
 
     start = time.time()
@@ -133,7 +133,7 @@ def process_urls(mode, urls, verbose, num_workers):
     if verbose:
         total_size = sum(size for url, size in urls)
         bw = total_size / (end - start)
-        print("%sed %d files, %s in total, in %d seconds (%s/s)."\
+        print('%sed %d files, %s in total, in %d seconds (%s/s).'\
               % (mode.capitalize(),
                  len(urls),
                  with_unit(total_size),
@@ -237,23 +237,23 @@ def op_list_prefix_nonrecursive(prefix_urls):
 
 def exit(exit_code, url):
     if exit_code == ERROR_INVALID_URL:
-        msg = "Invalid url: %s" % url.url
+        msg = 'Invalid url: %s' % url.url
     elif exit_code == ERROR_NOT_FULL_PATH:
-        msg = "URL not a full path: %s" % url.url
+        msg = 'URL not a full path: %s' % url.url
     elif exit_code == ERROR_URL_NOT_FOUND:
-        msg = "URL not found: %s" % url.url
+        msg = 'URL not found: %s' % url.url
     elif exit_code == ERROR_URL_ACCESS_DENIED:
-        msg = "Access denied to URL: %s" % url.url
+        msg = 'Access denied to URL: %s' % url.url
     elif exit_code == ERROR_WORKER_EXCEPTION:
-        msg = "Download failed"
+        msg = 'Download failed'
     elif exit_code == ERROR_VERIFY_FAILED:
-        msg = "Verification failed for URL %s, local file %s"\
+        msg = 'Verification failed for URL %s, local file %s'\
               % (url.url, url.local)
     elif exit_code == ERROR_LOCAL_FILE_NOT_FOUND:
-        msg = "Local file not found: %s" % url
+        msg = 'Local file not found: %s' % url
     else:
-        msg = "Unknown error"
-    print("s3op failed:\n%s" % msg, file=sys.stderr)
+        msg = 'Unknown error'
+    print('s3op failed:\n%s' % msg, file=sys.stderr)
     sys.exit(exit_code)
 
 def verify_results(urls, verbose=False):
@@ -313,18 +313,18 @@ def parallel_op(op, lst, num_workers):
 def cli():
     pass
 
-@cli.command('list', help="List S3 objects")
-@click.option("--inputs",
+@cli.command('list', help='List S3 objects')
+@click.option('--inputs',
               type=click.Path(exists=True),
-              help="Read input prefixes from the given file.")
-@click.option("--num-workers",
+              help='Read input prefixes from the given file.')
+@click.option('--num-workers',
               default=NUM_WORKERS_DEFAULT,
               show_default=True,
-              help="Number of concurrent connections.")
-@click.option("--recursive/--no-recursive",
+              help='Number of concurrent connections.')
+@click.option('--recursive/--no-recursive',
               default=False,
               show_default=True,
-              help="Download prefixes recursively.")
+              help='Download prefixes recursively.')
 @click.argument('prefixes', nargs=-1)
 def lst(prefixes,
         inputs=None,
@@ -357,32 +357,32 @@ def lst(prefixes,
         else:
             print(format_triplet(url.prefix, url.url, str(size)))
 
-@cli.command(help="Upload files to S3")
-@click.option("--file",
+@cli.command(help='Upload files to S3')
+@click.option('--file',
               'files',
               type=(click.Path(exists=True), str),
               multiple=True,
-              help="Local file->S3Url pair to upload. "
-                   "Can be specified multiple times.")
-@click.option("--filelist",
+              help='Local file->S3Url pair to upload. '
+                   'Can be specified multiple times.')
+@click.option('--filelist',
               type=click.Path(exists=True),
-              help="Read local file -> S3 URL mappings from the given file.")
-@click.option("--num-workers",
+              help='Read local file -> S3 URL mappings from the given file.')
+@click.option('--num-workers',
               default=NUM_WORKERS_DEFAULT,
               show_default=True,
-              help="Number of concurrent connections.")
-@click.option("--verbose/--no-verbose",
+              help='Number of concurrent connections.')
+@click.option('--verbose/--no-verbose',
               default=True,
               show_default=True,
-              help="Print status information on stderr.")
-@click.option("--overwrite/--no-overwrite",
+              help='Print status information on stderr.')
+@click.option('--overwrite/--no-overwrite',
               default=True,
               show_default=True,
-              help="Overwrite key if it already exists in S3.")
-@click.option("--listing/--no-listing",
+              help='Overwrite key if it already exists in S3.')
+@click.option('--listing/--no-listing',
               default=False,
               show_default=True,
-              help="Print S3 URLs upload to on stdout.")
+              help='Print S3 URLs upload to on stdout.')
 def put(files=None,
         filelist=None,
         num_workers=None,
@@ -433,35 +433,35 @@ def _populate_prefixes(prefixes, inputs):
             prefixes.extend(l.strip() for l in f)
     return list(map(url_unquote, prefixes))
 
-@cli.command(help="Download files from S3")
-@click.option("--recursive/--no-recursive",
+@cli.command(help='Download files from S3')
+@click.option('--recursive/--no-recursive',
               default=False,
               show_default=True,
-              help="Download prefixes recursively.")
-@click.option("--num-workers",
+              help='Download prefixes recursively.')
+@click.option('--num-workers',
               default=NUM_WORKERS_DEFAULT,
               show_default=True,
-              help="Number of concurrent connections.")
-@click.option("--inputs",
+              help='Number of concurrent connections.')
+@click.option('--inputs',
               type=click.Path(exists=True),
-              help="Read input prefixes from the given file.")
-@click.option("--verify/--no-verify",
+              help='Read input prefixes from the given file.')
+@click.option('--verify/--no-verify',
               default=True,
               show_default=True,
-              help="Verify that files were loaded correctly.")
-@click.option("--allow-missing/--no-allow-missing",
+              help='Verify that files were loaded correctly.')
+@click.option('--allow-missing/--no-allow-missing',
               default=False,
               show_default=True,
-              help="Do not exit if missing files are detected. "\
-                   "Implies --verify.")
-@click.option("--verbose/--no-verbose",
+              help='Do not exit if missing files are detected. '\
+                   'Implies --verify.')
+@click.option('--verbose/--no-verbose',
               default=True,
               show_default=True,
-              help="Print status information on stderr.")
-@click.option("--listing/--no-listing",
+              help='Print status information on stderr.')
+@click.option('--listing/--no-listing',
               default=False,
               show_default=True,
-              help="Print S3 URL -> local file mapping on stdout.")
+              help='Print S3 URL -> local file mapping on stdout.')
 @click.argument('prefixes', nargs=-1)
 def get(prefixes,
         recursive=None,
