@@ -103,11 +103,11 @@ class LocalMetadataProvider(MetadataProvider):
 
         if sub_type == 'artifact':
             meta_path = LocalMetadataProvider._get_metadir(*args[:obj_order])
+            result = []
             if meta_path is None:
-                return None
+                return result
             attempt_done_files = os.path.join(meta_path, 'sysmeta_attempt-done_*')
             attempts_done = sorted(glob.iglob(attempt_done_files))
-            result = []
             if attempts_done:
                 successful_attempt = int(LocalMetadataProvider._read_json_file(
                     attempts_done[-1])['value'])
@@ -118,15 +118,13 @@ class LocalMetadataProvider(MetadataProvider):
                     meta_path, '%d_artifact_%s.json' % (successful_attempt, which_artifact))
                 for obj in glob.iglob(artifact_files):
                     result.append(LocalMetadataProvider._read_json_file(obj))
-            if len(result) == 1:
-                return result[0]
             return result
 
         if sub_type == 'metadata':
             result = []
             meta_path = LocalMetadataProvider._get_metadir(*args[:obj_order])
             if meta_path is None:
-                return None
+                return result
             files = os.path.join(meta_path, 'sysmeta_*')
             for obj in glob.iglob(files):
                 result.append(LocalMetadataProvider._read_json_file(obj))
@@ -134,11 +132,11 @@ class LocalMetadataProvider(MetadataProvider):
 
         # For the other types, we locate all the objects we need to find and return them
         obj_path = LocalMetadataProvider._make_path(*args[:obj_order], create_on_absent=False)
+        result = []
         if obj_path is None:
-            return None
+            return result
         skip_dirs = '*/'*(sub_order - obj_order)
         all_meta = os.path.join(obj_path, skip_dirs, LocalDataStore.METADATA_DIR)
-        result = []
         for meta_path in glob.iglob(all_meta):
             self_file = os.path.join(meta_path, '_self.json')
             if os.path.isfile(self_file):
