@@ -54,9 +54,13 @@ class MetaflowTask(object):
         for var, param in self.flow._get_parameters():
             # make the parameter a read-only property
             # note x=x binds the current value of x to the closure
-            setattr(self.flow.__class__,
-                    var,
-                    property(fget=lambda _, var=var, parameter_ds=parameter_ds: parameter_ds[var]))
+            def property_setter(_, cls=self.flow.__class__, var=var, parameter_ds=parameter_ds):
+                v = parameter_ds[var]
+                setattr(cls, var, property(fget=lambda _, val=v: val))
+                return v
+
+            setattr(self.flow.__class__, var,
+                    property(fget=property_setter))
             vars.append(var)
         self.flow._datastore.passdown_partial(parameter_ds, vars)
 
